@@ -5,7 +5,7 @@ use warnings;
 use 5.008;
 use IPC::SysV qw(SEM_UNDO IPC_NOWAIT);
 
-our $VERSION = 0.09;
+our $VERSION = 0.11;
 
 ############
 ## Public ##
@@ -15,17 +15,14 @@ sub new
 {
 	my $class = shift;
 	my $args  = ref($_[0]) ? $_[0] : {@_};
-
-	# check for required arguments
+	# check for required arguments.
 	die "'key' is required"       unless defined($args->{key});
 	die "'number' is required"    unless defined($args->{number});
 	die "'semaphore' is required" unless (ref($args->{semaphore}) eq 'IPC::Semaphore');
-
 	# 'cleanup_object' determines whether or not we'll be cleaning up in DESTROY
 	if (!defined($args->{cleanup_object})) {
 		$args->{cleanup_object} = 1;
 	}
-
 	my $self = bless($args, $class);
 	# blow up if the system doesn't have this resource in the set
 	if (!defined($self->value)) {
@@ -33,7 +30,6 @@ sub new
 		die $self->{number} . ' is not a valid resource for semaphore [' . $self->{key}
 			. "] which only has [$total] total resources. The resources start at 0.";
 	}
-
 	return bless($args, $class);
 }
 
@@ -50,7 +46,6 @@ sub lockWaitTimeout
 {
 	my $self    = shift;
 	my $timeout = shift || 3;
-
 	my $lock;
 	eval {
 		local $SIG{ALRM} = sub { die "alarm\n" };
@@ -58,11 +53,9 @@ sub lockWaitTimeout
 		$lock = $self->_lock;
 		alarm 0;
 	};
-
 	if (!$lock) {
 		return 0;
 	}
-
 	return 1;
 }
 
@@ -70,7 +63,6 @@ sub lockWaitTimeoutDie
 {
 	my $self    = shift;
 	my $timeout = shift || 3;
-
 	my $lock;
 	eval {
 		local $SIG{ALRM} = sub { die "alarm\n" };
@@ -78,11 +70,9 @@ sub lockWaitTimeoutDie
 		$lock = $self->_lock;
 		alarm 0;
 	};
-
 	if (!$lock) {
 		die "could not establish lock after $timeout seconds";
 	}
-
 	return 1;
 }
 
@@ -129,6 +119,7 @@ sub _add_value
 sub DESTROY
 {
 	my $self = shift;
+	return unless $self->{cleanup_object};
 	if (defined($self->{_locks})) {
 		if ($self->{_locks} > 0) {
 			while ($self->{_locks} > 0) {
